Editing UMI Template Files
==========================

`archetypal` can read an UMI Template File using the command:

.. code-block:: python

    >>> from archetypal import UmiTemplateLibrary
    >>> template_library = UmiTemplateLibrary.open()

which returns an :class:`~archetypal.umi_template.UmiTemplateLibrary` object.

